@@ -14,6 +14,7 @@
 
 
 import os
+import warnings
 
 import appdirs
 import yaml
@@ -119,10 +120,11 @@ class OpenStackConfig(object):
         self.envvar_key = os.environ.pop('OS_CLOUD_NAME', 'envvars')
         if self.envvar_key in self.cloud_config['clouds']:
             raise exceptions.OpenStackConfigException(
-                'clouds.yaml defines a cloud named "{0}", but'
-                ' OS_CLOUD_NAME is also set to "{0}". Please rename'
+                '"{0}" defines a cloud named "{1}", but'
+                ' OS_CLOUD_NAME is also set to "{1}". Please rename'
                 ' either your environment based cloud, or one of your'
-                ' file-based clouds.'.format(self.envvar_key))
+                ' file-based clouds.'.format(self.config_filename,
+                                             self.envvar_key))
 
         envvars = _get_os_environ()
         if envvars:
@@ -217,6 +219,11 @@ class OpenStackConfig(object):
         # for this.
         profile_name = our_cloud.get('profile', our_cloud.get('cloud', None))
         if profile_name:
+            if 'cloud' in our_cloud:
+                warnings.warn(
+                    "{0} use the keyword 'cloud' to reference a known "
+                    "vendor profile. This has been deprecated in favor of the "
+                    "'profile' keyword.".format(self.config_filename))
             vendor_filename, vendor_file = self._load_vendor_file()
             if vendor_file and profile_name in vendor_file['public-clouds']:
                 _auth_update(cloud, vendor_file['public-clouds'][profile_name])
@@ -225,7 +232,9 @@ class OpenStackConfig(object):
                     _auth_update(cloud, vendors.CLOUD_DEFAULTS[profile_name])
                 except KeyError:
                     # Can't find the requested vendor config, go about business
-                    pass
+                    warnings.warn("Couldn't find the vendor profile '{0}', for"
+                                  " the cloud '{1}'".format(profile_name,
+                                                            name))
 
         if 'auth' not in cloud:
             cloud['auth'] = dict()
@@ -251,10 +260,10 @@ class OpenStackConfig(object):
             target = None
             for key in possible_values:
                 if key in cloud:
-                    target = cloud[key]
+                    target = str(cloud[key])
                     del cloud[key]
                 if key in cloud['auth']:
-                    target = cloud['auth'][key]
+                    target = str(cloud['auth'][key])
                     del cloud['auth'][key]
             if target:
                 cloud['auth'][target_key] = target
